@@ -113,9 +113,14 @@ class TypesExtrasTests(ConnectingTestCase):
             psycopg2.extensions.adapt, Foo(), ext.ISQLQuote, None)
         try:
             psycopg2.extensions.adapt(Foo(), ext.ISQLQuote, None)
-        except psycopg2.ProgrammingError, err:
+        except psycopg2.ProgrammingError as err:
             self.failUnless(str(err) == "can't adapt type 'Foo'")
 
+    def test_point_array(self):
+        # make sure a point array is never casted to a float array,
+        # see https://github.com/psycopg/psycopg2/issues/613
+        s = self.execute("""SELECT '{"(1,2)","(3,4)"}' AS foo""")
+        self.failUnless(s == """{"(1,2)","(3,4)"}""")
 
 def skip_if_no_hstore(f):
     @wraps(f)
@@ -173,8 +178,8 @@ class HstoreTestCase(ConnectingTestCase):
         m = re.match(br'hstore\(ARRAY\[([^\]]+)\], ARRAY\[([^\]]+)\]\)', q)
         self.assert_(m, repr(q))
 
-        kk = m.group(1).split(b", ")
-        vv = m.group(2).split(b", ")
+        kk = m.group(1).split(b",")
+        vv = m.group(2).split(b",")
         ii = zip(kk, vv)
         ii.sort()
 
@@ -886,7 +891,7 @@ class JsonTestCase(ConnectingTestCase):
 
         curs = self.conn.cursor()
         for obj in enumerate(objs):
-            self.assertEqual(curs.mogrify("%s", (Json(obj),)),
+            self.assertQuotedEqual(curs.mogrify("%s", (Json(obj),)),
                 psycopg2.extensions.QuotedString(json.dumps(obj)).getquoted())
 
     @skip_if_no_json_module
@@ -904,7 +909,7 @@ class JsonTestCase(ConnectingTestCase):
 
         def dumps(obj):
             return json.dumps(obj, cls=DecimalEncoder)
-        self.assertEqual(curs.mogrify("%s", (Json(obj, dumps=dumps),)),
+        self.assertQuotedEqual(curs.mogrify("%s", (Json(obj, dumps=dumps),)),
             b"'123.45'")
 
     @skip_if_no_json_module
@@ -923,7 +928,7 @@ class JsonTestCase(ConnectingTestCase):
 
         curs = self.conn.cursor()
         obj = Decimal('123.45')
-        self.assertEqual(curs.mogrify("%s", (MyJson(obj),)), b"'123.45'")
+        self.assertQuotedEqual(curs.mogrify("%s", (MyJson(obj),)), b"'123.45'")
 
     @skip_if_no_json_module
     def test_register_on_dict(self):
@@ -933,7 +938,8 @@ class JsonTestCase(ConnectingTestCase):
         try:
             curs = self.conn.cursor()
             obj = {'a': 123}
-            self.assertEqual(curs.mogrify("%s", (obj,)), b"""'{"a": 123}'""")
+            self.assertQuotedEqual(
+                curs.mogrify("%s", (obj,)), b"""'{"a": 123}'""")
         finally:
             del psycopg2.extensions.adapters[dict, ext.ISQLQuote]
 
@@ -1084,6 +1090,25 @@ class JsonTestCase(ConnectingTestCase):
         self.assert_(s.startswith("'"))
         self.assert_(s.endswith("'"))
 
+    @skip_if_no_json_module
+    @skip_before_postgres(8, 2)
+    def test_scs(self):
+        cnn_on = self.connect(options="-c standard_conforming_strings=on")
+        cur_on = cnn_on.cursor()
+        self.assertEqual(
+            cur_on.mogrify("%s", [psycopg2.extras.Json({'a': '"'})]),
+            b'\'{"a": "\\""}\'')
+
+        cnn_off = self.connect(options="-c standard_conforming_strings=off")
+        cur_off = cnn_off.cursor()
+        self.assertEqual(
+            cur_off.mogrify("%s", [psycopg2.extras.Json({'a': '"'})]),
+            b'E\'{"a": "\\\\""}\'')
+
+        self.assertEqual(
+            cur_on.mogrify("%s", [psycopg2.extras.Json({'a': '"'})]),
+            b'\'{"a": "\\""}\'')
+
 
 def skip_if_no_jsonb_type(f):
     return skip_before_postgres(9, 4)(f)
